@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2017	PgPool Global Development Group
+ * Copyright (c) 2003-2018	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -62,7 +62,7 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	/*
 	 * Handle misc process which is neccessary when query context exists.
 	 */
-	if (session_context->query_context != NULL && (!STREAM || (SL_MODE && !pool_is_doing_extended_query_message())))
+	if (session_context->query_context != NULL && !SL_MODE)
 		handle_query_context(backend);
 
 	/*
@@ -70,10 +70,8 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	 * read backend message according to the query context.
 	 * Also we set the transaction state at this point.
 	 */
-	if (STREAM && pool_is_doing_extended_query_message())
+	if (SL_MODE && pool_is_doing_extended_query_message())
 	{
-		p1 = NULL;
-
 		for (i=0;i<NUM_BACKENDS;i++)
 		{
 			if (VALID_BACKEND(i))
@@ -81,11 +79,7 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 				con = CONNECTION(backend, i);
 
 				if (pool_read(con, &len, sizeof(len)) < 0)
-				{
-					if (p1 != NULL)
-						pfree(p1);
 					return POOL_END;
-				}
 
 				len = ntohl(len);
 				len -= 4;
@@ -93,13 +87,7 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 
 				p = pool_read2(con, len);
 				if (p == NULL)
-				{
-					if (p1 != NULL)
-						pfree(p1);
 					return POOL_END;
-				}
-				if (p1 != NULL)
-					pfree(p1);
 				p1 = palloc(len);
 				memcpy(p1, p, len);
 
@@ -142,10 +130,16 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	 * do mismatch tuples process (forwarding to frontend is done in
 	 * handle_mismatch_tuples().
 	 */
-	if (STREAM && pool_is_doing_extended_query_message())
+	if (SL_MODE && pool_is_doing_extended_query_message())
 	{
 		int status;
 
+		if (p1 == NULL)
+		{
+			elog(WARNING, "CommandComplete: expected p1 is not NULL");
+			return POOL_END;
+		}
+
 		if (command_complete)
 			status = foward_command_complete(frontend, p1, len1);
 		else
@@ -172,12 +166,17 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 		 * If we are in streaming replication mode and we are doing extended
 		 * query, register query cache now.
 		 */
-		if (STREAM && pool_is_doing_extended_query_message())
+		if (SL_MODE && pool_is_doing_extended_query_message())
 		{
 			char *query;
 			Node *node;
 			char state;
 
+			if (session_context->query_context == NULL)
+			{
+				elog(WARNING, "expected query_contex is not NULL");
+				return POOL_END;
+			}
 			query = session_context->query_context->query_w_hex;
 			node = pool_get_parse_tree();
 			state = TSTATE(backend, MASTER_NODE_ID);
@@ -196,36 +195,11 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	 * If we are in streaming replication mode and we are doing extended
 	 * query, reset query in progress flag and prevoius pending message.
 	*/
-	if (STREAM && pool_is_doing_extended_query_message())
+	if (SL_MODE && pool_is_doing_extended_query_message())
 	{
 		pool_at_command_success(frontend, backend);
 		pool_unset_query_in_progress();
 		pool_pending_message_reset_previous_message();
-
-		if (session_context->query_context == NULL)
-		{
-			elog(WARNING, "At command complete there's no query context");
-		}
-		else
-		{
-			/*
-			 * Destroy query context if it is not referenced from sent
-			 * messages and pending messages except bound to named statements
-			 * or portals.  Named statements and portals should remain until
-			 * they are explicitly closed.
-			 */
-			if (can_query_context_destroy(session_context->query_context))
-
-			{
-				POOL_SENT_MESSAGE * msg = pool_get_sent_message_by_query_context(session_context->query_context);
-
-				if (!msg || (msg && *msg->name == '\0'))
-				{
-					pool_zap_query_context_in_sent_messages(session_context->query_context);
-					pool_query_context_destroy(session_context->query_context);
-				}
-			}
-		}
 	}
 
 	return POOL_CONTINUE;
